@@ -1,5 +1,10 @@
 package Data::Radius;
-our $VERSION = '1.0.2';
+
+use strict;
+use warnings;
+
+our $VERSION = '1.0.3';
+
 =head1 NAME
 
 Data::Radius - module to encode/decode RADIUS messages
@@ -37,6 +42,13 @@ Sergey Leschenko <sergle.ua at gmail.com>
 
 PortaOne Development Team <perl-radius at portaone.com> is the current module's maintainer at CPAN.
 
+=head1 COPYRIGHT & LICENSE
+ 
+Copyright 2016 PortaOne Inc., all rights reserved.
+ 
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
 =cut
 
 1;
